@@ -19,7 +19,10 @@ import grpc
 from pydgraph.meta import VERSION
 from pydgraph.proto import api_pb2_grpc as api_grpc
 
-from urllib.parse import urlparse
+try:
+    from urllib.parse import urlparse
+except ImportError:
+     from urlparse import urlparse
 
 __author__ = 'Garvit Pahal <garvit@dgraph.io>'
 __maintainer__ = 'Martin Martinez Rivera <martinmr@dgraph.io>'
@@ -84,6 +87,8 @@ class DgraphClientStub(object):
         del self.channel
         del self.stub
 
+    # from_slash_endpoint is deprecated and will be removed in v21.07 release. For more details,
+    # see: https://discuss.dgraph.io/t/regarding-slash-cloud-dgraph-endpoints-in-the-clients/13492
     @staticmethod
     def from_slash_endpoint(slash_end_point, api_key):
         """Returns Dgraph Client stub for the Slash GraphQL endpoint"""
